@@ -1,6 +1,6 @@
 from .image import Image, imageFragment
 from .program_invitation import ProgramInvitation
-from .program_module import ProgramModule
+from .program_module import ProgramModule, programModuleFragment
 from .program_track_action_response import (
     ProgramTrackActionResponse,
     programTrackActionResponseFragment,
@@ -8,3 +8,4 @@ from .program_track_action_response import (
 from .program_track_action import ProgramTrackAction, programTrackActionFragment
 from .program import Program
 from .session import Session
+from .tag import Tag, tagFragment
